from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Microsoft.Windows.AppNotifications
import win32more.Microsoft.Windows.AppNotifications.Builder
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Win32.System.WinRT
class AppNotificationAudioLooping(Enum, Int32):
    None_ = 0
    Loop = 1
class AppNotificationBuilder(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def AddArgument(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, key: WinRT_String, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetTimeStamp(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, value: win32more.Windows.Foundation.DateTime) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetDuration(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, duration: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationDuration) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetScenario(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationScenario) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def AddText(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, text: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def AddText2(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, text: WinRT_String, properties: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetAttributionText(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, text: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetAttributionText2(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, text: WinRT_String, language: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetInlineImage(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, imageUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetInlineImage2(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, imageUri: win32more.Windows.Foundation.Uri, imageCrop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetInlineImage3(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, imageUri: win32more.Windows.Foundation.Uri, imagecrop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop, alternateText: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetAppLogoOverride(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, imageUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetAppLogoOverride2(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, imageUri: win32more.Windows.Foundation.Uri, imageCrop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetAppLogoOverride3(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, imageUri: win32more.Windows.Foundation.Uri, imageCrop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop, alternateText: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetHeroImage(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, imageUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetHeroImage2(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, imageUri: win32more.Windows.Foundation.Uri, alternateText: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetAudioUri(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, audioUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetAudioUri2(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, audioUri: win32more.Windows.Foundation.Uri, loop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationAudioLooping) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetAudioEvent(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, appNotificationSoundEvent: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationSoundEvent) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetAudioEvent2(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, appNotificationSoundEvent: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationSoundEvent, loop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationAudioLooping) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def MuteAudio(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def AddTextBox(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, id: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def AddTextBox2(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, id: WinRT_String, placeHolderText: WinRT_String, title: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def AddButton(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def AddComboBox(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def AddProgressBar(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def BuildNotification(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder) -> win32more.Microsoft.Windows.AppNotifications.AppNotification: ...
    @winrt_mixinmethod
    def SetTag(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetGroup(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, group: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_classmethod
    def IsUrgentScenarioSupported(cls: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilderStatics) -> Boolean: ...
AppNotificationBuilderContract: UInt32 = 65536
class AppNotificationButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.AppNotificationButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton.CreateInstance(*args))
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_overload
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @CreateInstance.register
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButtonFactory, content: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Arguments(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]: ...
    @winrt_mixinmethod
    def put_Arguments(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]) -> Void: ...
    @winrt_mixinmethod
    def get_Icon(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_Icon(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_ToolTip(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_ToolTip(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ContextMenuPlacement(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> Boolean: ...
    @winrt_mixinmethod
    def put_ContextMenuPlacement(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ButtonStyle(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButtonStyle: ...
    @winrt_mixinmethod
    def put_ButtonStyle(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButtonStyle) -> Void: ...
    @winrt_mixinmethod
    def get_InputId(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_InputId(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_InvokeUri(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_InvokeUri(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_TargetAppId(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_TargetAppId(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def AddArgument(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, key: WinRT_String, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_mixinmethod
    def SetIcon(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_mixinmethod
    def SetToolTip(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_mixinmethod
    def SetContextMenuPlacement(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_mixinmethod
    def SetButtonStyle(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButtonStyle) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_mixinmethod
    def SetInputId(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_mixinmethod
    def SetInvokeUri(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, protocolUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_mixinmethod
    def SetInvokeUri2(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, protocolUri: win32more.Windows.Foundation.Uri, targetAppId: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_classmethod
    def IsToolTipSupported(cls: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButtonStatics) -> Boolean: ...
    @winrt_classmethod
    def IsButtonStyleSupported(cls: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButtonStatics) -> Boolean: ...
    Arguments = property(get_Arguments, put_Arguments)
    ButtonStyle = property(get_ButtonStyle, put_ButtonStyle)
    Content = property(get_Content, put_Content)
    ContextMenuPlacement = property(get_ContextMenuPlacement, put_ContextMenuPlacement)
    Icon = property(get_Icon, put_Icon)
    InputId = property(get_InputId, put_InputId)
    InvokeUri = property(get_InvokeUri, put_InvokeUri)
    TargetAppId = property(get_TargetAppId, put_TargetAppId)
    ToolTip = property(get_ToolTip, put_ToolTip)
class AppNotificationButtonStyle(Enum, Int32):
    Default = 0
    Success = 1
    Critical = 2
class AppNotificationComboBox(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBoxFactory, id: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]: ...
    @winrt_mixinmethod
    def put_Items(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox, value: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]) -> Void: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedItem(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_SelectedItem(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def AddItem(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox, id: WinRT_String, content: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox: ...
    @winrt_mixinmethod
    def SetTitle(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox: ...
    @winrt_mixinmethod
    def SetSelectedItem(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox, id: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox: ...
    Items = property(get_Items, put_Items)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    Title = property(get_Title, put_Title)
class AppNotificationDuration(Enum, Int32):
    Default = 0
    Long = 1
class AppNotificationImageCrop(Enum, Int32):
    Default = 0
    Circle = 1
class AppNotificationProgressBar(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Status(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar) -> Double: ...
    @winrt_mixinmethod
    def put_Value(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ValueStringOverride(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_ValueStringOverride(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def SetTitle(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_mixinmethod
    def BindTitle(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_mixinmethod
    def SetStatus(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_mixinmethod
    def BindStatus(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_mixinmethod
    def SetValue(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar, value: Double) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_mixinmethod
    def BindValue(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_mixinmethod
    def SetValueStringOverride(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_mixinmethod
    def BindValueStringOverride(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    Status = property(get_Status, put_Status)
    Title = property(get_Title, put_Title)
    Value = property(get_Value, put_Value)
    ValueStringOverride = property(get_ValueStringOverride, put_ValueStringOverride)
class AppNotificationScenario(Enum, Int32):
    Default = 0
    Reminder = 1
    Alarm = 2
    IncomingCall = 3
    Urgent = 4
class AppNotificationSoundEvent(Enum, Int32):
    Default = 0
    IM = 1
    Mail = 2
    Reminder = 3
    SMS = 4
    Alarm = 5
    Alarm2 = 6
    Alarm3 = 7
    Alarm4 = 8
    Alarm5 = 9
    Alarm6 = 10
    Alarm7 = 11
    Alarm8 = 12
    Alarm9 = 13
    Alarm10 = 14
    Call = 15
    Call2 = 16
    Call3 = 17
    Call4 = 18
    Call5 = 19
    Call6 = 20
    Call7 = 21
    Call8 = 22
    Call9 = 23
    Call10 = 24
class AppNotificationTextProperties(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties: ...
    @winrt_mixinmethod
    def get_Language(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Language(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IncomingCallAlignment(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties) -> Boolean: ...
    @winrt_mixinmethod
    def put_IncomingCallAlignment(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MaxLines(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxLines(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def SetLanguage(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties: ...
    @winrt_mixinmethod
    def SetIncomingCallAlignment(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties: ...
    @winrt_mixinmethod
    def SetMaxLines(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties, value: Int32) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties: ...
    IncomingCallAlignment = property(get_IncomingCallAlignment, put_IncomingCallAlignment)
    Language = property(get_Language, put_Language)
    MaxLines = property(get_MaxLines, put_MaxLines)
class IAppNotificationBuilder(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder'
    _iid_ = Guid('{e801d31f-ce03-505c-adec-8a02724ec9de}')
    @winrt_commethod(6)
    def AddArgument(self, key: WinRT_String, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(7)
    def SetTimeStamp(self, value: win32more.Windows.Foundation.DateTime) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(8)
    def SetDuration(self, duration: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationDuration) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(9)
    def SetScenario(self, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationScenario) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(10)
    def AddText(self, text: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(11)
    def AddText2(self, text: WinRT_String, properties: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(12)
    def SetAttributionText(self, text: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(13)
    def SetAttributionText2(self, text: WinRT_String, language: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(14)
    def SetInlineImage(self, imageUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(15)
    def SetInlineImage2(self, imageUri: win32more.Windows.Foundation.Uri, imageCrop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(16)
    def SetInlineImage3(self, imageUri: win32more.Windows.Foundation.Uri, imagecrop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop, alternateText: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(17)
    def SetAppLogoOverride(self, imageUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(18)
    def SetAppLogoOverride2(self, imageUri: win32more.Windows.Foundation.Uri, imageCrop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(19)
    def SetAppLogoOverride3(self, imageUri: win32more.Windows.Foundation.Uri, imageCrop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop, alternateText: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(20)
    def SetHeroImage(self, imageUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(21)
    def SetHeroImage2(self, imageUri: win32more.Windows.Foundation.Uri, alternateText: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(22)
    def SetAudioUri(self, audioUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(23)
    def SetAudioUri2(self, audioUri: win32more.Windows.Foundation.Uri, loop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationAudioLooping) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(24)
    def SetAudioEvent(self, appNotificationSoundEvent: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationSoundEvent) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(25)
    def SetAudioEvent2(self, appNotificationSoundEvent: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationSoundEvent, loop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationAudioLooping) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(26)
    def MuteAudio(self) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(27)
    def AddTextBox(self, id: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(28)
    def AddTextBox2(self, id: WinRT_String, placeHolderText: WinRT_String, title: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(29)
    def AddButton(self, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(30)
    def AddComboBox(self, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(31)
    def AddProgressBar(self, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(32)
    def BuildNotification(self) -> win32more.Microsoft.Windows.AppNotifications.AppNotification: ...
    @winrt_commethod(33)
    def SetTag(self, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(34)
    def SetGroup(self, group: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
class IAppNotificationBuilderStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilderStatics'
    _iid_ = Guid('{c7042d2a-d319-520e-a314-50081c8888cc}')
    @winrt_commethod(6)
    def IsUrgentScenarioSupported(self) -> Boolean: ...
class IAppNotificationButton(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton'
    _iid_ = Guid('{a7c03031-5634-5098-aec9-47ecb60c3499}')
    @winrt_commethod(6)
    def get_Content(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Content(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Arguments(self) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]: ...
    @winrt_commethod(9)
    def put_Arguments(self, value: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]) -> Void: ...
    @winrt_commethod(10)
    def get_Icon(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(11)
    def put_Icon(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(12)
    def get_ToolTip(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_ToolTip(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_ContextMenuPlacement(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_ContextMenuPlacement(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_ButtonStyle(self) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButtonStyle: ...
    @winrt_commethod(17)
    def put_ButtonStyle(self, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButtonStyle) -> Void: ...
    @winrt_commethod(18)
    def get_InputId(self) -> WinRT_String: ...
    @winrt_commethod(19)
    def put_InputId(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(20)
    def get_InvokeUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(21)
    def put_InvokeUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(22)
    def get_TargetAppId(self) -> WinRT_String: ...
    @winrt_commethod(23)
    def put_TargetAppId(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(24)
    def AddArgument(self, key: WinRT_String, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_commethod(25)
    def SetIcon(self, value: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_commethod(26)
    def SetToolTip(self, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_commethod(27)
    def SetContextMenuPlacement(self) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_commethod(28)
    def SetButtonStyle(self, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButtonStyle) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_commethod(29)
    def SetInputId(self, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_commethod(30)
    def SetInvokeUri(self, protocolUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_commethod(31)
    def SetInvokeUri2(self, protocolUri: win32more.Windows.Foundation.Uri, targetAppId: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    Arguments = property(get_Arguments, put_Arguments)
    ButtonStyle = property(get_ButtonStyle, put_ButtonStyle)
    Content = property(get_Content, put_Content)
    ContextMenuPlacement = property(get_ContextMenuPlacement, put_ContextMenuPlacement)
    Icon = property(get_Icon, put_Icon)
    InputId = property(get_InputId, put_InputId)
    InvokeUri = property(get_InvokeUri, put_InvokeUri)
    TargetAppId = property(get_TargetAppId, put_TargetAppId)
    ToolTip = property(get_ToolTip, put_ToolTip)
class IAppNotificationButtonFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.IAppNotificationButtonFactory'
    _iid_ = Guid('{4f109286-0a6d-5a5e-9e8f-9fe31669fbb8}')
    @winrt_commethod(6)
    def CreateInstance(self, content: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
class IAppNotificationButtonStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.IAppNotificationButtonStatics'
    _iid_ = Guid('{fead7c18-4144-59a4-9611-86b7e8191853}')
    @winrt_commethod(6)
    def IsToolTipSupported(self) -> Boolean: ...
    @winrt_commethod(7)
    def IsButtonStyleSupported(self) -> Boolean: ...
class IAppNotificationComboBox(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox'
    _iid_ = Guid('{4547c9e2-4815-538c-be26-040ce17f8b62}')
    @winrt_commethod(6)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]: ...
    @winrt_commethod(7)
    def put_Items(self, value: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]) -> Void: ...
    @winrt_commethod(8)
    def get_Title(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_Title(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_SelectedItem(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_SelectedItem(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def AddItem(self, id: WinRT_String, content: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox: ...
    @winrt_commethod(13)
    def SetTitle(self, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox: ...
    @winrt_commethod(14)
    def SetSelectedItem(self, id: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox: ...
    Items = property(get_Items, put_Items)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    Title = property(get_Title, put_Title)
class IAppNotificationComboBoxFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBoxFactory'
    _iid_ = Guid('{1b31b5b0-9d86-59ed-8629-a79498ab5d4b}')
    @winrt_commethod(6)
    def CreateInstance(self, id: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox: ...
class IAppNotificationProgressBar(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar'
    _iid_ = Guid('{fced62f2-2074-5641-8630-87a14315ac86}')
    @winrt_commethod(6)
    def get_Title(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Title(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Status(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_Status(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_Value(self) -> Double: ...
    @winrt_commethod(11)
    def put_Value(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_ValueStringOverride(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_ValueStringOverride(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def SetTitle(self, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_commethod(15)
    def BindTitle(self) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_commethod(16)
    def SetStatus(self, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_commethod(17)
    def BindStatus(self) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_commethod(18)
    def SetValue(self, value: Double) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_commethod(19)
    def BindValue(self) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_commethod(20)
    def SetValueStringOverride(self, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_commethod(21)
    def BindValueStringOverride(self) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    Status = property(get_Status, put_Status)
    Title = property(get_Title, put_Title)
    Value = property(get_Value, put_Value)
    ValueStringOverride = property(get_ValueStringOverride, put_ValueStringOverride)
class IAppNotificationTextProperties(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties'
    _iid_ = Guid('{23a30d0b-5258-5853-932e-9521a3642afb}')
    @winrt_commethod(6)
    def get_Language(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Language(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_IncomingCallAlignment(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IncomingCallAlignment(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_MaxLines(self) -> Int32: ...
    @winrt_commethod(11)
    def put_MaxLines(self, value: Int32) -> Void: ...
    @winrt_commethod(12)
    def SetLanguage(self, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties: ...
    @winrt_commethod(13)
    def SetIncomingCallAlignment(self) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties: ...
    @winrt_commethod(14)
    def SetMaxLines(self, value: Int32) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties: ...
    IncomingCallAlignment = property(get_IncomingCallAlignment, put_IncomingCallAlignment)
    Language = property(get_Language, put_Language)
    MaxLines = property(get_MaxLines, put_MaxLines)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.DirectComposition
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.UI.Animation
UI_ANIMATION_SECONDS_EVENTUALLY: Int32 = -1
UI_ANIMATION_REPEAT_INDEFINITELY: Int32 = -1
UI_ANIMATION_REPEAT_INDEFINITELY_CONCLUDE_AT_END: Int32 = -1
UI_ANIMATION_REPEAT_INDEFINITELY_CONCLUDE_AT_START: Int32 = -2
UI_ANIMATION_SECONDS_INFINITE: Int32 = -1
class IUIAnimationInterpolator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7815cbba-ddf7-478c-a46c-7b6c738b7978}')
    @commethod(3)
    def SetInitialValueAndVelocity(self, initialValue: Double, initialVelocity: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetDuration(self, duration: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetDuration(self, duration: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetFinalValue(self, value: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def InterpolateValue(self, offset: Double, value: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def InterpolateVelocity(self, offset: Double, velocity: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetDependencies(self, initialValueDependencies: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES), initialVelocityDependencies: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES), durationDependencies: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationInterpolator2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ea76aff8-ea22-4a23-a0ef-a6a966703518}')
    @commethod(3)
    def GetDimension(self, dimension: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetInitialValueAndVelocity(self, initialValue: POINTER(Double), initialVelocity: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetDuration(self, duration: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetDuration(self, duration: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetFinalValue(self, value: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def InterpolateValue(self, offset: Double, value: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def InterpolateVelocity(self, offset: Double, velocity: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetPrimitiveInterpolation(self, interpolation: win32more.Windows.Win32.UI.Animation.IUIAnimationPrimitiveInterpolation, cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetDependencies(self, initialValueDependencies: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES), initialVelocityDependencies: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES), durationDependencies: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationLoopIterationChangeHandler2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{2d3b15a4-4762-47ab-a030-b23221df3ae0}')
    @commethod(3)
    def OnLoopIterationChanged(self, storyboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2, id: UIntPtr, newIterationCount: UInt32, oldIterationCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9169896c-ac8d-4e7d-94e5-67fa4dc2f2e8}')
    @commethod(3)
    def CreateAnimationVariable(self, initialValue: Double, variable: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationVariable)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ScheduleTransition(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition, timeNow: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateStoryboard(self, storyboard: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def FinishAllStoryboards(self, completionDeadline: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def AbandonAllStoryboards(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Update(self, timeNow: Double, updateResult: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_UPDATE_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetVariableFromTag(self, object: win32more.Windows.Win32.System.Com.IUnknown, id: UInt32, variable: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationVariable)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetStoryboardFromTag(self, object: win32more.Windows.Win32.System.Com.IUnknown, id: UInt32, storyboard: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetStatus(self, status: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MANAGER_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetAnimationMode(self, mode: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def Pause(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Resume(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetManagerEventHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationManagerEventHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def SetCancelPriorityComparison(self, comparison: win32more.Windows.Win32.UI.Animation.IUIAnimationPriorityComparison) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def SetTrimPriorityComparison(self, comparison: win32more.Windows.Win32.UI.Animation.IUIAnimationPriorityComparison) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetCompressPriorityComparison(self, comparison: win32more.Windows.Win32.UI.Animation.IUIAnimationPriorityComparison) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def SetConcludePriorityComparison(self, comparison: win32more.Windows.Win32.UI.Animation.IUIAnimationPriorityComparison) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetDefaultLongestAcceptableDelay(self, delay: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def Shutdown(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationManager2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d8b6f7d4-4109-4d3f-acee-879926968cb1}')
    @commethod(3)
    def CreateAnimationVectorVariable(self, initialValue: POINTER(Double), cDimension: UInt32, variable: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateAnimationVariable(self, initialValue: Double, variable: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def ScheduleTransition(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2, timeNow: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateStoryboard(self, storyboard: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def FinishAllStoryboards(self, completionDeadline: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def AbandonAllStoryboards(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Update(self, timeNow: Double, updateResult: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_UPDATE_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetVariableFromTag(self, object: win32more.Windows.Win32.System.Com.IUnknown, id: UInt32, variable: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetStoryboardFromTag(self, object: win32more.Windows.Win32.System.Com.IUnknown, id: UInt32, storyboard: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def EstimateNextEventTime(self, seconds: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetStatus(self, status: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MANAGER_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def SetAnimationMode(self, mode: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def Pause(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def Resume(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def SetManagerEventHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationManagerEventHandler2, fRegisterForNextAnimationEvent: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetCancelPriorityComparison(self, comparison: win32more.Windows.Win32.UI.Animation.IUIAnimationPriorityComparison2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def SetTrimPriorityComparison(self, comparison: win32more.Windows.Win32.UI.Animation.IUIAnimationPriorityComparison2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetCompressPriorityComparison(self, comparison: win32more.Windows.Win32.UI.Animation.IUIAnimationPriorityComparison2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def SetConcludePriorityComparison(self, comparison: win32more.Windows.Win32.UI.Animation.IUIAnimationPriorityComparison2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def SetDefaultLongestAcceptableDelay(self, delay: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def Shutdown(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationManagerEventHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{783321ed-78a3-4366-b574-6af607a64788}')
    @commethod(3)
    def OnManagerStatusChanged(self, newStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MANAGER_STATUS, previousStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MANAGER_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationManagerEventHandler2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f6e022ba-bff3-42ec-9033-e073f33e83c3}')
    @commethod(3)
    def OnManagerStatusChanged(self, newStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MANAGER_STATUS, previousStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MANAGER_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationPrimitiveInterpolation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bab20d63-4361-45da-a24f-ab8508846b5b}')
    @commethod(3)
    def AddCubic(self, dimension: UInt32, beginOffset: Double, constantCoefficient: Single, linearCoefficient: Single, quadraticCoefficient: Single, cubicCoefficient: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddSinusoidal(self, dimension: UInt32, beginOffset: Double, bias: Single, amplitude: Single, frequency: Single, phase: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationPriorityComparison(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{83fa9b74-5f86-4618-bc6a-a2fac19b3f44}')
    @commethod(3)
    def HasPriority(self, scheduledStoryboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard, newStoryboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard, priorityEffect: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_PRIORITY_EFFECT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationPriorityComparison2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5b6d7a37-4621-467c-8b05-70131de62ddb}')
    @commethod(3)
    def HasPriority(self, scheduledStoryboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2, newStoryboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2, priorityEffect: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_PRIORITY_EFFECT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationStoryboard(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a8ff128f-9bf9-4af1-9e67-e5e410defb84}')
    @commethod(3)
    def AddTransition(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddKeyframeAtOffset(self, existingKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME, offset: Double, keyframe: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def AddKeyframeAfterTransition(self, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition, keyframe: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def AddTransitionAtKeyframe(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition, startKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def AddTransitionBetweenKeyframes(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition, startKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME, endKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def RepeatBetweenKeyframes(self, startKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME, endKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME, repetitionCount: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def HoldVariable(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetLongestAcceptableDelay(self, delay: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Schedule(self, timeNow: Double, schedulingResult: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SCHEDULING_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Conclude(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def Finish(self, completionDeadline: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Abandon(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetTag(self, object: win32more.Windows.Win32.System.Com.IUnknown, id: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetTag(self, object: POINTER(win32more.Windows.Win32.System.Com.IUnknown), id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetStatus(self, status: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetElapsedTime(self, elapsedTime: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def SetStoryboardEventHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboardEventHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationStoryboard2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ae289cd2-12d4-4945-9419-9e41be034df2}')
    @commethod(3)
    def AddTransition(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddKeyframeAtOffset(self, existingKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME, offset: Double, keyframe: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def AddKeyframeAfterTransition(self, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2, keyframe: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def AddTransitionAtKeyframe(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2, startKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def AddTransitionBetweenKeyframes(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2, transition: win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2, startKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME, endKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def RepeatBetweenKeyframes(self, startKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME, endKeyframe: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_KEYFRAME, cRepetition: Double, repeatMode: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_REPEAT_MODE, pIterationChangeHandler: win32more.Windows.Win32.UI.Animation.IUIAnimationLoopIterationChangeHandler2, id: UIntPtr, fRegisterForNextAnimationEvent: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def HoldVariable(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetLongestAcceptableDelay(self, delay: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetSkipDuration(self, secondsDuration: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Schedule(self, timeNow: Double, schedulingResult: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SCHEDULING_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def Conclude(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Finish(self, completionDeadline: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def Abandon(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def SetTag(self, object: win32more.Windows.Win32.System.Com.IUnknown, id: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetTag(self, object: POINTER(win32more.Windows.Win32.System.Com.IUnknown), id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetStatus(self, status: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetElapsedTime(self, elapsedTime: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetStoryboardEventHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboardEventHandler2, fRegisterStatusChangeForNextAnimationEvent: win32more.Windows.Win32.Foundation.BOOL, fRegisterUpdateForNextAnimationEvent: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationStoryboardEventHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3d5c9008-ec7c-4364-9f8a-9af3c58cbae6}')
    @commethod(3)
    def OnStoryboardStatusChanged(self, storyboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard, newStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS, previousStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnStoryboardUpdated(self, storyboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationStoryboardEventHandler2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bac5f55a-ba7c-414c-b599-fbf850f553c6}')
    @commethod(3)
    def OnStoryboardStatusChanged(self, storyboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2, newStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS, previousStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnStoryboardUpdated(self, storyboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTimer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6b0efad1-a053-41d6-9085-33a689144665}')
    @commethod(3)
    def SetTimerUpdateHandler(self, updateHandler: win32more.Windows.Win32.UI.Animation.IUIAnimationTimerUpdateHandler, idleBehavior: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_IDLE_BEHAVIOR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetTimerEventHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationTimerEventHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Enable(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Disable(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def IsEnabled(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetTime(self, seconds: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetFrameRateThreshold(self, framesPerSecond: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTimerClientEventHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bedb4db6-94fa-4bfb-a47f-ef2d9e408c25}')
    @commethod(3)
    def OnTimerClientStatusChanged(self, newStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_TIMER_CLIENT_STATUS, previousStatus: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_TIMER_CLIENT_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTimerEventHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{274a7dea-d771-4095-abbd-8df7abd23ce3}')
    @commethod(3)
    def OnPreUpdate(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnPostUpdate(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def OnRenderingTooSlow(self, framesPerSecond: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTimerUpdateHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{195509b7-5d5e-4e3e-b278-ee3759b367ad}')
    @commethod(3)
    def OnUpdate(self, timeNow: Double, result: POINTER(win32more.Windows.Win32.UI.Animation.UI_ANIMATION_UPDATE_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetTimerClientEventHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationTimerClientEventHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def ClearTimerClientEventHandler(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTransition(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{dc6ce252-f731-41cf-b610-614b6ca049ad}')
    @commethod(3)
    def SetInitialValue(self, value: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetInitialVelocity(self, velocity: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def IsDurationKnown(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetDuration(self, duration: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTransition2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{62ff9123-a85a-4e9b-a218-435a93e268fd}')
    @commethod(3)
    def GetDimension(self, dimension: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetInitialValue(self, value: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetInitialVectorValue(self, value: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetInitialVelocity(self, velocity: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetInitialVectorVelocity(self, velocity: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def IsDurationKnown(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetDuration(self, duration: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTransitionFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{fcd91e03-3e3b-45ad-bbb1-6dfc8153743d}')
    @commethod(3)
    def CreateTransition(self, interpolator: win32more.Windows.Win32.UI.Animation.IUIAnimationInterpolator, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTransitionFactory2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{937d4916-c1a6-42d5-88d8-30344d6efe31}')
    @commethod(3)
    def CreateTransition(self, interpolator: win32more.Windows.Win32.UI.Animation.IUIAnimationInterpolator2, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTransitionLibrary(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ca5a14b1-d24f-48b8-8fe4-c78169ba954e}')
    @commethod(3)
    def CreateInstantaneousTransition(self, finalValue: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateConstantTransition(self, duration: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateDiscreteTransition(self, delay: Double, finalValue: Double, hold: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateLinearTransition(self, duration: Double, finalValue: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CreateLinearTransitionFromSpeed(self, speed: Double, finalValue: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CreateSinusoidalTransitionFromVelocity(self, duration: Double, period: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CreateSinusoidalTransitionFromRange(self, duration: Double, minimumValue: Double, maximumValue: Double, period: Double, slope: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SLOPE, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CreateAccelerateDecelerateTransition(self, duration: Double, finalValue: Double, accelerationRatio: Double, decelerationRatio: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateReversalTransition(self, duration: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def CreateCubicTransition(self, duration: Double, finalValue: Double, finalVelocity: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateSmoothStopTransition(self, maximumDuration: Double, finalValue: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateParabolicTransitionFromAcceleration(self, finalValue: Double, finalVelocity: Double, acceleration: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationTransitionLibrary2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{03cfae53-9580-4ee3-b363-2ece51b4af6a}')
    @commethod(3)
    def CreateInstantaneousTransition(self, finalValue: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateInstantaneousVectorTransition(self, finalValue: POINTER(Double), cDimension: UInt32, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateConstantTransition(self, duration: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateDiscreteTransition(self, delay: Double, finalValue: Double, hold: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CreateDiscreteVectorTransition(self, delay: Double, finalValue: POINTER(Double), cDimension: UInt32, hold: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CreateLinearTransition(self, duration: Double, finalValue: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CreateLinearVectorTransition(self, duration: Double, finalValue: POINTER(Double), cDimension: UInt32, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CreateLinearTransitionFromSpeed(self, speed: Double, finalValue: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateLinearVectorTransitionFromSpeed(self, speed: Double, finalValue: POINTER(Double), cDimension: UInt32, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def CreateSinusoidalTransitionFromVelocity(self, duration: Double, period: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateSinusoidalTransitionFromRange(self, duration: Double, minimumValue: Double, maximumValue: Double, period: Double, slope: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SLOPE, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateAccelerateDecelerateTransition(self, duration: Double, finalValue: Double, accelerationRatio: Double, decelerationRatio: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def CreateReversalTransition(self, duration: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def CreateCubicTransition(self, duration: Double, finalValue: Double, finalVelocity: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def CreateCubicVectorTransition(self, duration: Double, finalValue: POINTER(Double), finalVelocity: POINTER(Double), cDimension: UInt32, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def CreateSmoothStopTransition(self, maximumDuration: Double, finalValue: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def CreateParabolicTransitionFromAcceleration(self, finalValue: Double, finalVelocity: Double, acceleration: Double, transition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def CreateCubicBezierLinearTransition(self, duration: Double, finalValue: Double, x1: Double, y1: Double, x2: Double, y2: Double, ppTransition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def CreateCubicBezierLinearVectorTransition(self, duration: Double, finalValue: POINTER(Double), cDimension: UInt32, x1: Double, y1: Double, x2: Double, y2: Double, ppTransition: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationTransition2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationVariable(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8ceeb155-2849-4ce5-9448-91ff70e1e4d9}')
    @commethod(3)
    def GetValue(self, value: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetFinalValue(self, finalValue: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetPreviousValue(self, previousValue: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetIntegerValue(self, value: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetFinalIntegerValue(self, finalValue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetPreviousIntegerValue(self, previousValue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetCurrentStoryboard(self, storyboard: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetLowerBound(self, bound: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetUpperBound(self, bound: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetRoundingMode(self, mode: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_ROUNDING_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetTag(self, object: win32more.Windows.Win32.System.Com.IUnknown, id: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetTag(self, object: POINTER(win32more.Windows.Win32.System.Com.IUnknown), id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetVariableChangeHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationVariableChangeHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def SetVariableIntegerChangeHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationVariableIntegerChangeHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationVariable2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4914b304-96ab-44d9-9e77-d5109b7e7466}')
    @commethod(3)
    def GetDimension(self, dimension: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetValue(self, value: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetVectorValue(self, value: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetCurve(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetVectorCurve(self, animation: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetFinalValue(self, finalValue: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetFinalVectorValue(self, finalValue: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetPreviousValue(self, previousValue: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetPreviousVectorValue(self, previousValue: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetIntegerValue(self, value: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetIntegerVectorValue(self, value: POINTER(Int32), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetFinalIntegerValue(self, finalValue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetFinalIntegerVectorValue(self, finalValue: POINTER(Int32), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetPreviousIntegerValue(self, previousValue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetPreviousIntegerVectorValue(self, previousValue: POINTER(Int32), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetCurrentStoryboard(self, storyboard: POINTER(win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def SetLowerBound(self, bound: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetLowerBoundVector(self, bound: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def SetUpperBound(self, bound: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def SetUpperBoundVector(self, bound: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def SetRoundingMode(self, mode: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_ROUNDING_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def SetTag(self, object: win32more.Windows.Win32.System.Com.IUnknown, id: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def GetTag(self, object: POINTER(win32more.Windows.Win32.System.Com.IUnknown), id: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def SetVariableChangeHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationVariableChangeHandler2, fRegisterForNextAnimationEvent: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def SetVariableIntegerChangeHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationVariableIntegerChangeHandler2, fRegisterForNextAnimationEvent: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def SetVariableCurveChangeHandler(self, handler: win32more.Windows.Win32.UI.Animation.IUIAnimationVariableCurveChangeHandler2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationVariableChangeHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6358b7ba-87d2-42d5-bf71-82e919dd5862}')
    @commethod(3)
    def OnValueChanged(self, storyboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable, newValue: Double, previousValue: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationVariableChangeHandler2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{63acc8d2-6eae-4bb0-b879-586dd8cfbe42}')
    @commethod(3)
    def OnValueChanged(self, storyboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2, newValue: POINTER(Double), previousValue: POINTER(Double), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationVariableCurveChangeHandler2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{72895e91-0145-4c21-9192-5aab40eddf80}')
    @commethod(3)
    def OnCurveChanged(self, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationVariableIntegerChangeHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bb3e1550-356e-44b0-99da-85ac6017865e}')
    @commethod(3)
    def OnIntegerValueChanged(self, storyboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable, newValue: Int32, previousValue: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIAnimationVariableIntegerChangeHandler2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{829b6cf1-4f3a-4412-ae09-b243eb4c6b58}')
    @commethod(3)
    def OnIntegerValueChanged(self, storyboard: win32more.Windows.Win32.UI.Animation.IUIAnimationStoryboard2, variable: win32more.Windows.Win32.UI.Animation.IUIAnimationVariable2, newValue: POINTER(Int32), previousValue: POINTER(Int32), cDimension: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
UIAnimationManager = Guid('{4c1fc63a-695c-47e8-a339-1a194be3d0b8}')
UIAnimationManager2 = Guid('{d25d8842-8884-4a4a-b321-091314379bdd}')
UIAnimationTimer = Guid('{bfcd4a0c-06b6-4384-b768-0daa792c380e}')
UIAnimationTransitionFactory = Guid('{8a9b1cdd-fcd7-419c-8b44-42fd17db1887}')
UIAnimationTransitionFactory2 = Guid('{84302f97-7f7b-4040-b190-72ac9d18e420}')
UIAnimationTransitionLibrary = Guid('{1d6322ad-aa85-4ef5-a828-86d71067d145}')
UIAnimationTransitionLibrary2 = Guid('{812f944a-c5c8-4cd9-b0a6-b3da802f228d}')
UI_ANIMATION_DEPENDENCIES = Int32
UI_ANIMATION_DEPENDENCY_NONE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES = 0
UI_ANIMATION_DEPENDENCY_INTERMEDIATE_VALUES: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES = 1
UI_ANIMATION_DEPENDENCY_FINAL_VALUE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES = 2
UI_ANIMATION_DEPENDENCY_FINAL_VELOCITY: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES = 4
UI_ANIMATION_DEPENDENCY_DURATION: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_DEPENDENCIES = 8
UI_ANIMATION_IDLE_BEHAVIOR = Int32
UI_ANIMATION_IDLE_BEHAVIOR_CONTINUE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_IDLE_BEHAVIOR = 0
UI_ANIMATION_IDLE_BEHAVIOR_DISABLE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_IDLE_BEHAVIOR = 1
UI_ANIMATION_KEYFRAME = IntPtr
UI_ANIMATION_MANAGER_STATUS = Int32
UI_ANIMATION_MANAGER_IDLE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MANAGER_STATUS = 0
UI_ANIMATION_MANAGER_BUSY: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MANAGER_STATUS = 1
UI_ANIMATION_MODE = Int32
UI_ANIMATION_MODE_DISABLED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MODE = 0
UI_ANIMATION_MODE_SYSTEM_DEFAULT: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MODE = 1
UI_ANIMATION_MODE_ENABLED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_MODE = 2
UI_ANIMATION_PRIORITY_EFFECT = Int32
UI_ANIMATION_PRIORITY_EFFECT_FAILURE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_PRIORITY_EFFECT = 0
UI_ANIMATION_PRIORITY_EFFECT_DELAY: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_PRIORITY_EFFECT = 1
UI_ANIMATION_REPEAT_MODE = Int32
UI_ANIMATION_REPEAT_MODE_NORMAL: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_REPEAT_MODE = 0
UI_ANIMATION_REPEAT_MODE_ALTERNATE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_REPEAT_MODE = 1
UI_ANIMATION_ROUNDING_MODE = Int32
UI_ANIMATION_ROUNDING_NEAREST: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_ROUNDING_MODE = 0
UI_ANIMATION_ROUNDING_FLOOR: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_ROUNDING_MODE = 1
UI_ANIMATION_ROUNDING_CEILING: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_ROUNDING_MODE = 2
UI_ANIMATION_SCHEDULING_RESULT = Int32
UI_ANIMATION_SCHEDULING_UNEXPECTED_FAILURE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SCHEDULING_RESULT = 0
UI_ANIMATION_SCHEDULING_INSUFFICIENT_PRIORITY: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SCHEDULING_RESULT = 1
UI_ANIMATION_SCHEDULING_ALREADY_SCHEDULED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SCHEDULING_RESULT = 2
UI_ANIMATION_SCHEDULING_SUCCEEDED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SCHEDULING_RESULT = 3
UI_ANIMATION_SCHEDULING_DEFERRED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SCHEDULING_RESULT = 4
UI_ANIMATION_SLOPE = Int32
UI_ANIMATION_SLOPE_INCREASING: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SLOPE = 0
UI_ANIMATION_SLOPE_DECREASING: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_SLOPE = 1
UI_ANIMATION_STORYBOARD_STATUS = Int32
UI_ANIMATION_STORYBOARD_BUILDING: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS = 0
UI_ANIMATION_STORYBOARD_SCHEDULED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS = 1
UI_ANIMATION_STORYBOARD_CANCELLED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS = 2
UI_ANIMATION_STORYBOARD_PLAYING: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS = 3
UI_ANIMATION_STORYBOARD_TRUNCATED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS = 4
UI_ANIMATION_STORYBOARD_FINISHED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS = 5
UI_ANIMATION_STORYBOARD_READY: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS = 6
UI_ANIMATION_STORYBOARD_INSUFFICIENT_PRIORITY: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_STORYBOARD_STATUS = 7
UI_ANIMATION_TIMER_CLIENT_STATUS = Int32
UI_ANIMATION_TIMER_CLIENT_IDLE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_TIMER_CLIENT_STATUS = 0
UI_ANIMATION_TIMER_CLIENT_BUSY: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_TIMER_CLIENT_STATUS = 1
UI_ANIMATION_UPDATE_RESULT = Int32
UI_ANIMATION_UPDATE_NO_CHANGE: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_UPDATE_RESULT = 0
UI_ANIMATION_UPDATE_VARIABLES_CHANGED: win32more.Windows.Win32.UI.Animation.UI_ANIMATION_UPDATE_RESULT = 1


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Gaming.Preview
GamesEnumerationContract: UInt32 = 131072


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.UI.Xaml
import win32more.Windows.UI.Xaml.Interop
import win32more.Windows.UI.Xaml.Media.Animation
import win32more.Windows.UI.Xaml.Navigation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
class FrameNavigationOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Navigation.IFrameNavigationOptions
    _classid_ = 'Windows.UI.Xaml.Navigation.FrameNavigationOptions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Navigation.FrameNavigationOptions.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Navigation.IFrameNavigationOptionsFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Navigation.FrameNavigationOptions: ...
    @winrt_mixinmethod
    def get_IsNavigationStackEnabled(self: win32more.Windows.UI.Xaml.Navigation.IFrameNavigationOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsNavigationStackEnabled(self: win32more.Windows.UI.Xaml.Navigation.IFrameNavigationOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TransitionInfoOverride(self: win32more.Windows.UI.Xaml.Navigation.IFrameNavigationOptions) -> win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    @winrt_mixinmethod
    def put_TransitionInfoOverride(self: win32more.Windows.UI.Xaml.Navigation.IFrameNavigationOptions, value: win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo) -> Void: ...
    IsNavigationStackEnabled = property(get_IsNavigationStackEnabled, put_IsNavigationStackEnabled)
    TransitionInfoOverride = property(get_TransitionInfoOverride, put_TransitionInfoOverride)
class IFrameNavigationOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Navigation.IFrameNavigationOptions'
    _iid_ = Guid('{b539ad2a-9fb7-520a-8f41-57a50c59cf92}')
    @winrt_commethod(6)
    def get_IsNavigationStackEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsNavigationStackEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_TransitionInfoOverride(self) -> win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    @winrt_commethod(9)
    def put_TransitionInfoOverride(self, value: win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo) -> Void: ...
    IsNavigationStackEnabled = property(get_IsNavigationStackEnabled, put_IsNavigationStackEnabled)
    TransitionInfoOverride = property(get_TransitionInfoOverride, put_TransitionInfoOverride)
class IFrameNavigationOptionsFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Navigation.IFrameNavigationOptionsFactory'
    _iid_ = Guid('{d4681e41-7e6d-5c7c-aca0-478681cc6fce}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Navigation.FrameNavigationOptions: ...
class INavigatingCancelEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Navigation.INavigatingCancelEventArgs'
    _iid_ = Guid('{fd1d67ae-eafb-4079-be80-6dc92a03aedf}')
    @winrt_commethod(6)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Cancel(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_NavigationMode(self) -> win32more.Windows.UI.Xaml.Navigation.NavigationMode: ...
    @winrt_commethod(9)
    def get_SourcePageType(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    Cancel = property(get_Cancel, put_Cancel)
    NavigationMode = property(get_NavigationMode, None)
    SourcePageType = property(get_SourcePageType, None)
class INavigatingCancelEventArgs2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Navigation.INavigatingCancelEventArgs2'
    _iid_ = Guid('{5407b704-8147-4343-838f-dd1ee908c137}')
    @winrt_commethod(6)
    def get_Parameter(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def get_NavigationTransitionInfo(self) -> win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    NavigationTransitionInfo = property(get_NavigationTransitionInfo, None)
    Parameter = property(get_Parameter, None)
class INavigationEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Navigation.INavigationEventArgs'
    _iid_ = Guid('{b6aa9834-6691-44d1-bdf7-58820c27b0d0}')
    @winrt_commethod(6)
    def get_Content(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def get_Parameter(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(8)
    def get_SourcePageType(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_commethod(9)
    def get_NavigationMode(self) -> win32more.Windows.UI.Xaml.Navigation.NavigationMode: ...
    @winrt_commethod(10)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(11)
    def put_Uri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    Content = property(get_Content, None)
    NavigationMode = property(get_NavigationMode, None)
    Parameter = property(get_Parameter, None)
    SourcePageType = property(get_SourcePageType, None)
    Uri = property(get_Uri, put_Uri)
class INavigationEventArgs2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Navigation.INavigationEventArgs2'
    _iid_ = Guid('{dbff71d9-979a-4b2e-a49b-3bb17fdef574}')
    @winrt_commethod(6)
    def get_NavigationTransitionInfo(self) -> win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    NavigationTransitionInfo = property(get_NavigationTransitionInfo, None)
class INavigationFailedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Navigation.INavigationFailedEventArgs'
    _iid_ = Guid('{11c1dff7-36c2-4102-b2ef-0217a97289b3}')
    @winrt_commethod(6)
    def get_Exception(self) -> win32more.Windows.Foundation.HResult: ...
    @winrt_commethod(7)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_Handled(self, value: Boolean) -> Void: ...
    @winrt_commethod(9)
    def get_SourcePageType(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    Exception = property(get_Exception, None)
    Handled = property(get_Handled, put_Handled)
    SourcePageType = property(get_SourcePageType, None)
class IPageStackEntry(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Navigation.IPageStackEntry'
    _iid_ = Guid('{ef8814a6-9388-4aca-8572-405194069080}')
    @winrt_commethod(6)
    def get_SourcePageType(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_commethod(7)
    def get_Parameter(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(8)
    def get_NavigationTransitionInfo(self) -> win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    NavigationTransitionInfo = property(get_NavigationTransitionInfo, None)
    Parameter = property(get_Parameter, None)
    SourcePageType = property(get_SourcePageType, None)
class IPageStackEntryFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Navigation.IPageStackEntryFactory'
    _iid_ = Guid('{4454048a-a8b9-4f78-9b84-1f51f58851ff}')
    @winrt_commethod(6)
    def CreateInstance(self, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: win32more.Windows.Win32.System.WinRT.IInspectable, navigationTransitionInfo: win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo) -> win32more.Windows.UI.Xaml.Navigation.PageStackEntry: ...
class IPageStackEntryStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Navigation.IPageStackEntryStatics'
    _iid_ = Guid('{aceff8e3-246c-4033-9f01-01cb0da5254e}')
    @winrt_commethod(6)
    def get_SourcePageTypeProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    SourcePageTypeProperty = property(get_SourcePageTypeProperty, None)
class LoadCompletedEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{aebaf785-43fc-4e2c-95c3-97ae84eabc8e}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Navigation.NavigationEventArgs) -> Void: ...
class NavigatedEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7bd1cf54-23cf-4cce-b2f5-4ce78d96896e}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Navigation.NavigationEventArgs) -> Void: ...
class NavigatingCancelEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Navigation.INavigatingCancelEventArgs
    _classid_ = 'Windows.UI.Xaml.Navigation.NavigatingCancelEventArgs'
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Windows.UI.Xaml.Navigation.INavigatingCancelEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Windows.UI.Xaml.Navigation.INavigatingCancelEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_NavigationMode(self: win32more.Windows.UI.Xaml.Navigation.INavigatingCancelEventArgs) -> win32more.Windows.UI.Xaml.Navigation.NavigationMode: ...
    @winrt_mixinmethod
    def get_SourcePageType(self: win32more.Windows.UI.Xaml.Navigation.INavigatingCancelEventArgs) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_mixinmethod
    def get_Parameter(self: win32more.Windows.UI.Xaml.Navigation.INavigatingCancelEventArgs2) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_NavigationTransitionInfo(self: win32more.Windows.UI.Xaml.Navigation.INavigatingCancelEventArgs2) -> win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    Cancel = property(get_Cancel, put_Cancel)
    NavigationMode = property(get_NavigationMode, None)
    NavigationTransitionInfo = property(get_NavigationTransitionInfo, None)
    Parameter = property(get_Parameter, None)
    SourcePageType = property(get_SourcePageType, None)
class NavigatingCancelEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{75d6a78f-a302-4489-9898-24ea49182910}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Navigation.NavigatingCancelEventArgs) -> Void: ...
class NavigationCacheMode(Enum, Int32):
    Disabled = 0
    Required = 1
    Enabled = 2
class NavigationEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Navigation.INavigationEventArgs
    _classid_ = 'Windows.UI.Xaml.Navigation.NavigationEventArgs'
    @winrt_mixinmethod
    def get_Content(self: win32more.Windows.UI.Xaml.Navigation.INavigationEventArgs) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_Parameter(self: win32more.Windows.UI.Xaml.Navigation.INavigationEventArgs) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_SourcePageType(self: win32more.Windows.UI.Xaml.Navigation.INavigationEventArgs) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_mixinmethod
    def get_NavigationMode(self: win32more.Windows.UI.Xaml.Navigation.INavigationEventArgs) -> win32more.Windows.UI.Xaml.Navigation.NavigationMode: ...
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.UI.Xaml.Navigation.INavigationEventArgs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_Uri(self: win32more.Windows.UI.Xaml.Navigation.INavigationEventArgs, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_NavigationTransitionInfo(self: win32more.Windows.UI.Xaml.Navigation.INavigationEventArgs2) -> win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    Content = property(get_Content, None)
    NavigationMode = property(get_NavigationMode, None)
    NavigationTransitionInfo = property(get_NavigationTransitionInfo, None)
    Parameter = property(get_Parameter, None)
    SourcePageType = property(get_SourcePageType, None)
    Uri = property(get_Uri, put_Uri)
class NavigationFailedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Navigation.INavigationFailedEventArgs
    _classid_ = 'Windows.UI.Xaml.Navigation.NavigationFailedEventArgs'
    @winrt_mixinmethod
    def get_Exception(self: win32more.Windows.UI.Xaml.Navigation.INavigationFailedEventArgs) -> win32more.Windows.Foundation.HResult: ...
    @winrt_mixinmethod
    def get_Handled(self: win32more.Windows.UI.Xaml.Navigation.INavigationFailedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Windows.UI.Xaml.Navigation.INavigationFailedEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SourcePageType(self: win32more.Windows.UI.Xaml.Navigation.INavigationFailedEventArgs) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    Exception = property(get_Exception, None)
    Handled = property(get_Handled, put_Handled)
    SourcePageType = property(get_SourcePageType, None)
class NavigationFailedEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4dab4671-12b2-43c7-b892-9be2dcd3e88d}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Navigation.NavigationFailedEventArgs) -> Void: ...
class NavigationMode(Enum, Int32):
    New = 0
    Back = 1
    Forward = 2
    Refresh = 3
class NavigationStoppedEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f0117ddb-12fa-4d8d-8b26-b383d09c2b3c}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Navigation.NavigationEventArgs) -> Void: ...
class _PageStackEntry_Meta_(ComPtr.__class__):
    pass
class PageStackEntry(ComPtr, metaclass=_PageStackEntry_Meta_):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Navigation.IPageStackEntry
    _classid_ = 'Windows.UI.Xaml.Navigation.PageStackEntry'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 3:
            super().__init__(move=win32more.Windows.UI.Xaml.Navigation.PageStackEntry.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Navigation.IPageStackEntryFactory, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: win32more.Windows.Win32.System.WinRT.IInspectable, navigationTransitionInfo: win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo) -> win32more.Windows.UI.Xaml.Navigation.PageStackEntry: ...
    @winrt_mixinmethod
    def get_SourcePageType(self: win32more.Windows.UI.Xaml.Navigation.IPageStackEntry) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_mixinmethod
    def get_Parameter(self: win32more.Windows.UI.Xaml.Navigation.IPageStackEntry) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_NavigationTransitionInfo(self: win32more.Windows.UI.Xaml.Navigation.IPageStackEntry) -> win32more.Windows.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    @winrt_classmethod
    def get_SourcePageTypeProperty(cls: win32more.Windows.UI.Xaml.Navigation.IPageStackEntryStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    NavigationTransitionInfo = property(get_NavigationTransitionInfo, None)
    Parameter = property(get_Parameter, None)
    SourcePageType = property(get_SourcePageType, None)
    _PageStackEntry_Meta_.SourcePageTypeProperty = property(get_SourcePageTypeProperty, None)


make_ready(__name__)
